class InvalidInputException(Exception):
    pass


def add_default_customerid_for_model(apps, model_name, objects,
                                     customer_id_field='customerid'):
    Customer = apps.get_model('symonitoring_model', 'Customer')
    all_customers = Customer.objects.all()
    num_customers = len(all_customers)
    if not num_customers:
        raise Customer.DoesNotExist(
            'There are no customers within the database. Please ensure that '
            'at least one customer exists'
        )
    try:
        customer_id = None
        help_text = ("\nPlease enter the ID of the customer for the existing "
                     "%s entries. Available customer IDs are:\n") % model_name
        for c in all_customers:
            help_text += "* %s - %s\n" % (c.pk, c.name)
        customer_id = input(help_text.encode("utf-8"))
    except (SyntaxError, NameError):
        raise InvalidInputException(
            'No or invalid input given. Please enter the customer ID'
        )
    try:
        print("\nCustomer ID %d was given, trying to get customer\n" %
              customer_id)
        customer = Customer.objects.get(pk=int(customer_id))
    except Customer.DoesNotExist:
        raise Customer.DoesNotExist(
            'Given customer ID `%s` not found. '
            'Please enter a valid customer ID'
            % customer_id
        )
    for object_ in objects:
        setattr(object_, customer_id_field, customer)
        object_.save()
