# -*- coding: utf-8 -*-
# pylint: disable=missing-docstring,unused-argument
from __future__ import unicode_literals

from django.db                   import migrations
from django.core                 import serializers
from django.db.utils             import IntegrityError
import django.db.transaction     as transaction

data = """
    [
        {
            "fields": {
                "description": "Show the nagios status overview link.",
                "globalonly": 1,
                "name": "Monitoring status"
            },
            "model": "symonitoring_model.permission",
            "pk": 51
        }
    ]
"""


class AddStatusPermission:
    @classmethod
    def forwards_func(cls, apps, schema_editor):
        dbname = schema_editor.connection.alias
        objects = serializers.deserialize(
            'json',
            data,
            ignorenonexistent=True
        )
        for obj in objects:
            try:
                with transaction.atomic(using=dbname):
                    obj.save(using=dbname)
            except IntegrityError:
                pass

    @classmethod
    def backwards_func(cls, apps, schema_editor):
        dbname = schema_editor.connection.alias
        objects = list(serializers.deserialize(
            'json',
            data,
            ignorenonexistent=True
        ))
        for obj in objects:
            try:
                with transaction.atomic(using=dbname):
                    obj.save(using=dbname)
            except IntegrityError:
                pass
        with transaction.atomic(using=dbname):
            for obj in objects:
                obj.object.delete(using=dbname)


class Migration(migrations.Migration):

    dependencies = [
        ('symonitoring_model', '0005_maintenance_comment_user_id_allow_null'),
    ]

    operations = [
        migrations.RunPython(
            AddStatusPermission.forwards_func,
            AddStatusPermission.backwards_func
        )
    ]
