# -*- coding: utf-8 -*-
# pylint: disable=missing-docstring,unused-argument
from __future__ import unicode_literals

from django.db                   import migrations
from django.core                 import serializers
from django.db.utils             import IntegrityError
import django.db.transaction     as transaction
from symonitoring_model.models   import User
import symonitoring_model.sql_migrators

class UpdateAuthenticationMethods:

    @classmethod
    def _update(cls, methods, apps, schema_editor):
        dbname = schema_editor.connection.alias
        (method_from, method_to) = methods
        user = User.objects.using(dbname).filter(
            authenticationmethod=method_from
        ).update(authenticationmethod=method_to)

    @classmethod
    def forwards_func(cls, apps, schema_editor):
        methods = (User.METHOD_MYSQL, User.METHOD_LOCAL)
        cls._update(methods, apps, schema_editor)

    @classmethod
    def backwards_func(cls, apps, schema_editor):
        methods = (User.METHOD_LOCAL, User.METHOD_MYSQL)
        cls._update(methods, apps, schema_editor)

class Migration(migrations.Migration):

    dependencies = [
       ('symonitoring_model', '0019_customer_default_role_id'),
    ]

    operations = [
        migrations.RunPython(
            UpdateAuthenticationMethods.forwards_func,
            UpdateAuthenticationMethods.backwards_func
        )
    ]
