# -*- coding: utf-8 -*-
# pylint: disable=missing-docstring,unused-argument

# System imports
from __future__ import unicode_literals
from django.db                   import migrations

# Project imports
import symonitoring_model.models as mod


def set_auth_method(model, old_auth_method, new_auth_method):
    for user in model.objects.filter(
            authenticationmethod=old_auth_method
    ):
        user.authenticationmethod = new_auth_method
        user.save()


def set_auth_method_to_local(apps, _):
    model = apps.get_model('symonitoring_model', 'User')
    set_auth_method(model, mod.User.METHOD_MYSQL, mod.User.METHOD_LOCAL)


def set_auth_method_to_mysql(apps, _):
    model = apps.get_model('symonitoring_model', 'User')
    set_auth_method(model, mod.User.METHOD_LOCAL, mod.User.METHOD_MYSQL)


class Migration(migrations.Migration):

    dependencies = [(
        'symonitoring_model',
        '0026_increase_authmethod_length_on_user'
    ), ]

    operations = [
        migrations.RunPython(
            code=set_auth_method_to_local,
            reverse_code=set_auth_method_to_mysql,
        )
    ]
