# -*- coding: utf-8 -*-
# pylint: disable=missing-docstring

from django.db import migrations


def add_permission(apps, _):
    Role           = apps.get_model('symonitoring_model', 'Role')
    Permission     = apps.get_model('symonitoring_model', 'Permission')
    RolePermission = apps.get_model('symonitoring_model', 'RolePermission')

    new_permissions = [
        {
            'name': 'Guidelines',
            'description': 'Access the guideline page.'
        },
        {
            'name': 'Guidelines write',
            'description': 'Write access for the guideline page.'
        },
    ]

    try:
        admin_role = Role.objects.get(name='Administrator')
    except Exception:
        # TODO
        admin_role = None

    for new_permission in new_permissions:
        permission, _ = Permission.objects.get_or_create(
            name        = new_permission['name'],
            description = new_permission['description'],
            globalonly  = True
        )

        if admin_role:
            rolePermission, _ = RolePermission.objects.get_or_create(
                roleid = admin_role,
                permissionid = permission
            )


class Migration(migrations.Migration):

    dependencies = [
            ('symonitoring_model', '0029_set_cascade_maintenance_tickets'),
    ]

    operations = [
        migrations.RunPython(add_permission)
    ]
