# -*- coding: UTF-8 -*-
# pylint: disable=missing-docstring,too-many-lines,no-member
from __future__ import unicode_literals
from django.db import models


class Alert(models.Model):
    STATE_UP          = 'UP'
    STATE_DOWN        = 'DOWN'
    STATE_UNREACHABLE = 'UNREACHABLE'
    STATE_OK          = 'OK'
    STATE_WARNING     = 'WARNING'
    STATE_UNKNOWN     = 'UNKNOWN'
    STATE_CRITICAL    = 'CRITICAL'

    CHOICES_STATE = (
        (STATE_UP,          STATE_UP),
        (STATE_DOWN,        STATE_DOWN),
        (STATE_UNREACHABLE, STATE_UNREACHABLE),
        (STATE_OK,          STATE_OK),
        (STATE_WARNING,     STATE_WARNING),
        (STATE_UNKNOWN,     STATE_UNKNOWN),
        (STATE_CRITICAL,    STATE_CRITICAL),
    )

    id = models.AutoField(primary_key=True)
    customerid = models.ForeignKey('Customer', db_column='customerId')
    hostid = models.ForeignKey('Host', db_column='hostId')
    commandid = models.ForeignKey('Command', db_column='commandId')
    serviceinstanceid = models.ForeignKey(
        'Hostserviceinstance', db_column='serviceInstanceId', null=True
    )
    slaid = models.ForeignKey('Sla', db_column='slaId', null=True)
    slacustomerid = models.ForeignKey(
        'Customer',
        db_column='slaCustomerId',
        null=True,
        related_name='slaalert_set',
    )
    datetimeoccured = models.DateTimeField(db_column='datetimeOccured')
    datetimefirstnotification = models.DateTimeField(
        db_column='datetimeFirstNotification', null=True
    )
    datetimelastnotification = models.DateTimeField(
        db_column='datetimeLastNotification', null=True
    )
    datetimeacknowledged = models.DateTimeField(
        db_column='datetimeAcknowledged', null=True
    )
    datetimerecovery = models.DateTimeField(
        db_column='datetimeRecovery',
        null=True,
        db_index=True,
    )
    state = models.CharField(max_length=11, choices=CHOICES_STATE)
    output = models.TextField()
    acknowledgedby = models.ForeignKey(
        'User', db_column='acknowledgedBy', null=True
    )
    acknowledged = models.BooleanField(default=False, db_index=True)
    acknowledgedautomatically = models.BooleanField(
        default=False,
        db_column='acknowledgedAutomatically',
        db_index=True,
    )
    acknowledgedprocessed = models.BooleanField(
        default=False,
        db_column='acknowledgedProcessed',
        db_index=True,
    )
    comment = models.TextField(null=True, blank=True)
    problemid = models.IntegerField(
        db_column='problemId',
        null=True,
        db_index=True
    )
    lastproblemid = models.IntegerField(
        db_column='lastProblemId',
        null=True,
        db_index=True
    )

    class Meta:
        db_table = 'Alert'
        index_together = (('acknowledged', 'acknowledgedprocessed'),)


class AlertTimeframeState(models.Model):
    id = models.AutoField(primary_key=True)
    timeframe = models.ForeignKey('Timeframe')
    alert = models.ForeignKey('Alert')
    rule_index = models.IntegerField(default=0)
    user_index = models.IntegerField(default=0)
    restart_index = models.IntegerField(default=0)

    class Meta:
        db_table = 'AlertTimeframeState'


class Alertcomment(models.Model):
    id = models.AutoField(primary_key=True)
    alertid = models.ForeignKey(Alert, db_column='alertId')
    userid = models.ForeignKey('User', db_column='userId')
    timestamp = models.DateTimeField(auto_now_add=True)
    comment = models.TextField()

    class Meta:
        db_table = 'AlertComment'


class AlertcommentAlerttag(models.Model):
    id = models.AutoField(primary_key=True)
    tagid = models.ForeignKey('Alerttag', db_column='tagId')
    commentid = models.ForeignKey(Alertcomment, db_column='commentId')

    class Meta:
        db_table = 'AlertComment_AlertTag'
        unique_together = (('tagid', 'commentid'),)
        index_together = (('tagid', 'commentid'),)


class Alertlog(models.Model):
    id = models.AutoField(primary_key=True)
    typeid = models.ForeignKey('Notificationtype', db_column='typeId')
    userid = models.ForeignKey('User', db_column='userId', null=True)
    alertid = models.ForeignKey(Alert, db_column='alertId')
    timestamp = models.DateTimeField(auto_now_add=True)
    hasfailed = models.BooleanField(default=False, db_column='hasFailed')

    class Meta:
        db_table = 'AlertLog'


class AlertnotificationExcludeUser(models.Model):
    id = models.AutoField(primary_key=True)
    userid = models.ForeignKey('User', db_column='userId')
    slaactionid = models.ForeignKey('Slaaction', db_column='slaActionId')
    customerid = models.ForeignKey('Customer', db_column='customerId')

    class Meta:
        db_table = 'AlertNotification_Exclude_User'


class Alerttag(models.Model):
    id = models.AutoField(primary_key=True)
    name = models.CharField(unique=True, max_length=255)
    description = models.CharField(max_length=255)

    class Meta:
        db_table = 'AlertTag'


class Alerttemplate(models.Model):
    id = models.AutoField(primary_key=True)
    name = models.CharField(unique=True, max_length=32)
    description = models.CharField(max_length=255)
    content = models.TextField()
    slaactionid = models.ForeignKey('Slaaction', db_column='slaActionId')

    class Meta:
        db_table = 'AlertTemplate'


class AlerttemplateUser(models.Model):
    id = models.AutoField(primary_key=True)
    userid = models.ForeignKey('User', db_column='userId', null=True)
    templateid = models.ForeignKey(Alerttemplate, db_column='templateId')
    slaactionid = models.ForeignKey('Slaaction', db_column='slaActionId')

    class Meta:
        db_table = 'AlertTemplate_User'
        unique_together = (('userid', 'templateid', 'slaactionid'),)
        index_together = (('userid', 'templateid', 'slaactionid'),)


class Architecture(models.Model):
    id = models.AutoField(primary_key=True)
    name = models.CharField(max_length=28)

    class Meta:
        db_table = 'Architecture'


class ArchitectureHostos(models.Model):
    id = models.AutoField(primary_key=True)
    architectureid = models.ForeignKey(
        Architecture, db_column='architectureId'
    )
    hostosid = models.ForeignKey('Hostos', db_column='hostOSId')

    class Meta:
        db_table = 'Architecture_HostOS'
        unique_together = (('architectureid', 'hostosid'),)
        index_together = (('architectureid', 'hostosid'),)


class Auditlog(models.Model):
    OPERATION_CREATE  = 'create'
    OPERATION_UPDATE  = 'update'
    OPERATION_DELETE  = 'delete'

    CHOICES_OPERATION = (
        (OPERATION_CREATE, OPERATION_CREATE),
        (OPERATION_UPDATE, OPERATION_UPDATE),
        (OPERATION_DELETE, OPERATION_DELETE),
    )

    id = models.AutoField(primary_key=True)
    entity = models.CharField(max_length=40)
    entityid = models.IntegerField(db_column='entityID', null=True)
    entityname = models.CharField(
        db_column='entityName', max_length=255, blank=True
    )
    operation = models.CharField(max_length=6, choices=CHOICES_OPERATION)
    order = models.IntegerField()
    auditlogactionid = models.ForeignKey(
        'Auditlogaction', db_column='auditLogActionID'
    )

    class Meta:
        db_table = 'AuditLog'


class Auditlogaction(models.Model):
    id = models.AutoField(primary_key=True)
    userid = models.IntegerField(db_column='userID')
    username = models.CharField(
        db_column='userName', max_length=40, blank=True
    )
    timestamp = models.DateTimeField(auto_now=True)

    class Meta:
        db_table = 'AuditLogAction'


class Auditlogchange(models.Model):
    id = models.AutoField(primary_key=True)
    logentryid = models.ForeignKey(Auditlog, db_column='logEntryID')
    column = models.CharField(max_length=40)
    oldvalue = models.TextField(db_column='oldValue', blank=True, null=True)
    newvalue = models.TextField(db_column='newValue', blank=True, null=True)

    class Meta:
        db_table = 'AuditLogChange'


class Checkresult(models.Model):
    id = models.AutoField(primary_key=True)
    timestamp = models.DateTimeField(auto_now=True)
    hostid = models.ForeignKey('Host', db_column='hostId')
    serviceinstanceid = models.ForeignKey(
        'Hostserviceinstance', db_column='serviceInstanceId', null=True
    )
    available = models.IntegerField()

    class Meta:
        db_table = 'CheckResult'


class Command(models.Model):
    id = models.AutoField(primary_key=True)
    name = models.CharField(unique=True, max_length=255)
    description = models.CharField(max_length=255)
    commandline = models.TextField()
    v6capable = models.BooleanField(default=False, db_column='v6Capable')
    isdeleted = models.BooleanField(default=False, db_column='isDeleted')

    class Meta:
        db_table = 'Command'


class Customer(models.Model):
    id = models.AutoField(primary_key=True)
    parentid = models.ForeignKey('self', db_column='parentId', null=True)
    slaid = models.ForeignKey('Sla', db_column='slaId')
    name = models.CharField(unique=True, max_length=255)
    email = models.CharField(max_length=255, null=True)
    warnhoster = models.IntegerField(db_column='warnHoster')
    wiki = models.CharField(max_length=255, blank=True, null=True)
    comment = models.TextField(null=True)
    passwordinformation = models.CharField(
        db_column='passwordInformation',
        max_length=255,
        null=True
    )
    passwordmaintenance = models.CharField(
        db_column='passwordMaintenance',
        max_length=255,
        null=True
    )
    lastaccess = models.DateField(db_column='lastAccess', null=True)
    ldapgroup = models.CharField(
        db_column='ldapGroup', max_length=255, blank=True, null=True
    )
    isenabled = models.BooleanField(default=True, db_column='isEnabled')
    isdeleted = models.BooleanField(default=False, db_column='isDeleted')
    defaultroleid = models.ForeignKey(
        'Role',
        db_column='defaultRoleId',
        null=True,
        blank=True,
    )

    class Meta:
        db_table = 'Customer'


class Customerinformation(models.Model):
    id = models.OneToOneField(Customer, db_column='id', primary_key=True)
    name = models.CharField(max_length=255, blank=True, null=True)
    address = models.CharField(max_length=255, blank=True, null=True)
    contacttechnical = models.CharField(
        db_column='contactTechnical', max_length=255, blank=True, null=True
    )
    contactcommercial = models.CharField(
        db_column='contactCommercial', max_length=255, blank=True, null=True
    )
    phoneregular = models.CharField(
        db_column='phoneRegular', max_length=255, blank=True, null=True
    )
    phoneemergency = models.CharField(
        db_column='phoneEmergency', max_length=255, blank=True, null=True
    )
    comment = models.TextField(blank=True, null=True)
    commentemergency = models.TextField(
        db_column='commentEmergency', blank=True, null=True
    )
    maycontact = models.BooleanField(default=False, db_column='mayContact')

    class Meta:
        db_table = 'CustomerInformation'


class Customerteam(models.Model):
    id = models.AutoField(primary_key=True)
    userid = models.ForeignKey('User', db_column='userId')
    customerid = models.ForeignKey(Customer, db_column='customerId')
    date = models.DateField(null=True, db_index=True)
    priority = models.IntegerField()

    class Meta:
        db_table = 'CustomerTeam'


class CustomerRole(models.Model):
    id = models.AutoField(primary_key=True)
    customerid = models.ForeignKey(Customer, db_column='customerId')
    roleid = models.ForeignKey('Role', db_column='roleId')
    ldapgroup = models.CharField(
        db_column='ldapGroup', max_length=255, blank=True
    )

    class Meta:
        db_table = 'Customer_Role'
        unique_together = (('roleid', 'ldapgroup'),)
        index_together = (('roleid', 'ldapgroup'),)


class Downtime(models.Model):
    id = models.AutoField(primary_key=True)
    hostid = models.ForeignKey('Host', db_column='hostId')
    serviceinstanceid = models.ForeignKey(
        'Hostserviceinstance',
        db_column='serviceInstanceId',
        blank=True,
        null=True
    )
    datetimefrom = models.DateTimeField(
        db_column='datetimeFrom', db_index=True
    )
    datetimeto = models.DateTimeField(
        db_column='datetimeTo',
        null=True,
        db_index=True
    )
    durationhours = models.FloatField(db_column='durationHours', null=True)
    rrule = models.TextField(null=True)

    class Meta:
        db_table = 'Downtime'


class Guideline(models.Model):
    id = models.AutoField(primary_key=True)
    content = models.TextField(blank=True, null=True)
    needsmanualinstallation = models.BooleanField(
        default=False, db_column='needsManualInstallation'
    )
    filename = models.CharField(max_length=255, blank=True, null=True)
    created = models.DateTimeField(null=True)
    updated = models.DateTimeField(null=True)
    commandid = models.ForeignKey(Command, db_column='commandId')
    userid = models.ForeignKey('User', db_column='userId')
    versionid = models.ForeignKey('Hostosversion', db_column='versionId')

    class Meta:
        db_table = 'Guideline'


class GuidelineEntry(models.Model):
    id          = models.AutoField(primary_key=True)
    guidelineid = models.ForeignKey(
        Guideline,
        db_column='guidelineId',
        on_delete=models.CASCADE
    )
    entryid     = models.IntegerField(db_column='entryId')
    kind        = models.CharField(max_length=100)

    class Meta:
        db_table = 'GuidelineEntry'
        index_together = ['entryid', 'kind']


class Hold(models.Model):
    id = models.AutoField(primary_key=True)
    nagioslogid = models.ForeignKey('Nagioslog', db_column='nagioslogId')

    class Meta:
        db_table = 'Hold'


class HoldInform(models.Model):
    id = models.AutoField(primary_key=True)
    nagioslogid = models.ForeignKey('Nagioslog', db_column='nagioslogId')

    class Meta:
        db_table = 'HoldInform'


class Host(models.Model):
    id = models.AutoField(primary_key=True)
    customerid = models.ForeignKey(Customer, db_column='customerId')
    slaid = models.ForeignKey('Sla', db_column='slaId', null=True)
    dependencyid = models.ForeignKey(
        'self',
        db_column='dependencyId',
        null=True,
        related_name='dependency_set',
        on_delete=models.SET_NULL,
    )
    satelliteid = models.ForeignKey(
        'self',
        db_column='satelliteId',
        null=True,
        related_name='satellite_set',
        on_delete=models.SET_NULL,
    )
    osid = models.ForeignKey('Hostos', db_column='osId')
    osversionid = models.ForeignKey(
        'Hostosversion', db_column='osVersionId', null=True
    )
    typeid = models.ForeignKey('Hosttype', db_column='typeId', null=True)
    inheritsla = models.BooleanField(default=False, db_column='inheritSla')
    checkhostalive = models.BooleanField(
        default=True, db_column='checkHostAlive'
    )
    hostname = models.CharField(unique=True, max_length=255)
    description = models.CharField(max_length=255)
    ipv4 = models.CharField(db_column='IPv4', max_length=15)
    ipv6 = models.CharField(db_column='IPv6', max_length=39, null=True)
    issatellite = models.BooleanField(default=False, db_column='isSatellite')
    isenabled = models.BooleanField(default=True, db_column='isEnabled')
    hastrouble = models.BooleanField(default=False, db_column='hasTrouble')
    comment = models.TextField(null=True)
    datetimecreated = models.DateTimeField(
        auto_now_add=True, db_column='datetimeCreated'
    )
    exportdate = models.DateTimeField(db_column='exportDate', null=True)
    version = models.IntegerField()
    password = models.CharField(max_length=255, null=True)
    isdeleted = models.IntegerField(db_column='isDeleted')
    wiki = models.CharField(max_length=255, null=True)

    class Meta:
        db_table = 'Host'


class Hostgroup(models.Model):
    id = models.AutoField(primary_key=True)
    customerid = models.ForeignKey(Customer, db_column='customerId')
    name = models.CharField(max_length=255)
    description = models.CharField(max_length=255)

    class Meta:
        db_table = 'HostGroup'


class HostgroupHost(models.Model):
    id = models.AutoField(primary_key=True)
    hostgroupid = models.ForeignKey(Hostgroup, db_column='hostGroupId')
    hostid = models.ForeignKey(Host, db_column='hostId')

    class Meta:
        db_table = 'HostGroup_Host'
        unique_together = (('hostgroupid', 'hostid'),)
        index_together = (('hostgroupid', 'hostid'),)


class Hostos(models.Model):
    id = models.AutoField(primary_key=True)
    name = models.CharField(unique=True, max_length=255)
    image = models.CharField(max_length=255)

    class Meta:
        db_table = 'HostOS'


class Hostosversion(models.Model):
    id = models.AutoField(primary_key=True)
    osid = models.ForeignKey(Hostos, db_column='osId')
    architectureid = models.ForeignKey(
        Architecture, db_column='architectureId'
    )
    name = models.CharField(max_length=255)
    shortname = models.CharField(
        db_column='shortName', max_length=20, blank=True, null=True
    )

    class Meta:
        db_table = 'HostOSVersion'


class Hostservice(models.Model):
    id = models.AutoField(primary_key=True)
    hostid = models.ForeignKey(Host, db_column='hostId')
    serviceid = models.ForeignKey('Service', db_column='serviceId')

    class Meta:
        db_table = 'HostService'


class Hostserviceargument(models.Model):
    id = models.AutoField(primary_key=True)
    instanceid = models.ForeignKey(
        'Hostserviceinstance', db_column='instanceId', null=True
    )
    serviceargumentid = models.ForeignKey(
        'Serviceargument', db_column='serviceArgumentId'
    )
    assignedvalue = models.CharField(
        db_column='assignedValue', max_length=255, null=True
    )

    class Meta:
        db_table = 'HostServiceArgument'


class Hostserviceinstance(models.Model):
    id = models.AutoField(primary_key=True)
    hostserviceid = models.ForeignKey(Hostservice, db_column='hostServiceId')
    slaid = models.ForeignKey('Sla', db_column='slaId', null=True)
    name = models.CharField(max_length=40, null=True, db_index=True)
    ispassive = models.BooleanField(default=False, db_column='isPassive')
    foravailability = models.BooleanField(
        default=False, db_column='forAvailability'
    )
    hastrouble = models.BooleanField(default=False, db_column='hasTrouble')
    datetimecreated = models.DateTimeField(
        auto_now_add=True, db_column='datetimeCreated'
    )
    isenabled = models.BooleanField(default=True, db_column='isEnabled')

    def _display_name(self):
        if self.name is None:
            return self.hostserviceid.serviceid.name
        return '{}__{}'.format(
            self.hostserviceid.serviceid.name,
            self.name
        )
    display_name = property(_display_name)

    class Meta:
        db_table = 'HostServiceInstance'


class Hosttype(models.Model):
    id = models.AutoField(primary_key=True)
    name = models.CharField(max_length=32)
    short = models.CharField(max_length=2)

    class Meta:
        db_table = 'HostType'


class Importcommand(models.Model):
    id = models.AutoField(primary_key=True)
    fileid = models.ForeignKey('Importfile', db_column='fileId')
    commandid = models.ForeignKey(Command, db_column='commandId', null=True)
    command_name = models.CharField(max_length=255, null=True)
    command_line = models.TextField(null=True)
    name = models.CharField(max_length=255, null=True)
    register = models.BooleanField(default=False)

    class Meta:
        db_table = 'ImportCommand'


class Importcommandinclude(models.Model):
    id = models.AutoField(primary_key=True)
    importcommandid = models.ForeignKey(
        Importcommand, db_column='importCommandId'
    )
    name = models.CharField(max_length=255)

    class Meta:
        db_table = 'ImportCommandInclude'


class Importfile(models.Model):
    id = models.AutoField(primary_key=True)
    name = models.CharField(max_length=255)
    hosts = models.IntegerField()
    services = models.IntegerField()
    commands = models.IntegerField()
    hostgroups = models.IntegerField()

    class Meta:
        db_table = 'ImportFile'


class Importhost(models.Model):
    id = models.AutoField(primary_key=True)
    fileid = models.ForeignKey(Importfile, db_column='fileId')
    hostid = models.ForeignKey(Host, db_column='hostId', null=True)
    customerid = models.ForeignKey(Customer, db_column='customerId', null=True)
    osid = models.ForeignKey(Hostos, db_column='osId', null=True)
    host_name = models.CharField(max_length=255, blank=True, null=True)
    alias = models.CharField(max_length=255, blank=True, null=True)
    address = models.CharField(max_length=255, blank=True, null=True)
    parents = models.TextField(blank=True, null=True)
    hostgroups = models.TextField(blank=True, null=True)
    name = models.CharField(max_length=255, blank=True, null=True)
    register = models.BooleanField(default=False)

    class Meta:
        db_table = 'ImportHost'


class Importhostinclude(models.Model):
    id = models.AutoField(primary_key=True)
    importhostid = models.ForeignKey(Importhost, db_column='importHostId')
    name = models.CharField(max_length=255)

    class Meta:
        db_table = 'ImportHostInclude'


class Importhostgroup(models.Model):
    id = models.AutoField(primary_key=True)
    fileid = models.ForeignKey(Importfile, db_column='fileId')
    hostgroupid = models.ForeignKey(
        Hostgroup, db_column='hostgroupId', null=True
    )
    hostgroup_name = models.CharField(max_length=255, null=True)
    alias = models.CharField(max_length=255, blank=True, null=True)
    members = models.TextField(blank=True, null=True)
    hostgroup_members = models.TextField(blank=True, null=True)
    name = models.CharField(max_length=255, blank=True, null=True)
    register = models.BooleanField(default=False)

    class Meta:
        db_table = 'ImportHostgroup'


class Importhostgroupinclude(models.Model):
    id = models.AutoField(primary_key=True)
    importhostgroupid = models.ForeignKey(
        Importhostgroup, db_column='importHostgroupId'
    )
    name = models.CharField(max_length=255)

    class Meta:
        db_table = 'ImportHostgroupInclude'


class Importservice(models.Model):
    id = models.AutoField(primary_key=True)
    fileid = models.ForeignKey(Importfile, db_column='fileId')
    serviceid = models.ForeignKey('Service', db_column='serviceId', null=True)
    host_name = models.CharField(max_length=255, null=True)
    hostgroup_name = models.CharField(max_length=255, blank=True, null=True)
    service_description = models.CharField(
        max_length=255, blank=True, null=True
    )
    check_command = models.CharField(max_length=255, blank=True, null=True)
    max_check_attempts = models.IntegerField(null=True)
    check_interval = models.IntegerField(null=True)
    retry_interval = models.IntegerField(null=True)
    name = models.CharField(max_length=255, null=True)
    register = models.BooleanField(default=False)

    class Meta:
        db_table = 'ImportService'


class Importserviceinclude(models.Model):
    id = models.AutoField(primary_key=True)
    importserviceid = models.ForeignKey(
        Importservice, db_column='importServiceId'
    )
    name = models.CharField(max_length=255)

    class Meta:
        db_table = 'ImportServiceInclude'


class Infofeed(models.Model):
    id = models.AutoField(primary_key=True)
    userid = models.ForeignKey('User', db_column='userId')
    onalert = models.BooleanField(default=False, db_column='onAlert')
    onwarning = models.BooleanField(default=False, db_column='onWarning')
    onacknowledge = models.BooleanField(
        default=False, db_column='onAcknowledge'
    )

    class Meta:
        db_table = 'Infofeed'


class InfofeedCustomer(models.Model):
    id = models.AutoField(primary_key=True)
    infofeedid = models.ForeignKey(Infofeed, db_column='infofeedId')
    customerid = models.ForeignKey(Customer, db_column='customerId')

    class Meta:
        db_table = 'Infofeed_Customer'
        unique_together = (('infofeedid', 'customerid'),)
        index_together = (('infofeedid', 'customerid'),)


class InfofeedCustomerExcludedHosts(models.Model):
    id = models.AutoField(primary_key=True)
    infofeedcustomerid = models.ForeignKey(
        InfofeedCustomer, db_column='infofeedCustomerId'
    )
    hostid = models.ForeignKey(Host, db_column='hostId')

    class Meta:
        db_table = 'Infofeed_Customer_Excluded_Hosts'
        unique_together = (('infofeedcustomerid', 'hostid'),)
        index_together = (('infofeedcustomerid', 'hostid'),)


class InfofeedHost(models.Model):
    id = models.AutoField(primary_key=True)
    infofeedid = models.ForeignKey(Infofeed, db_column='infofeedId')
    hostid = models.ForeignKey(Host, db_column='hostId')

    class Meta:
        db_table = 'Infofeed_Host'
        unique_together = (('infofeedid', 'hostid'),)
        index_together = (('infofeedid', 'hostid'),)


class InfofeedHostgroup(models.Model):
    id = models.AutoField(primary_key=True)
    infofeedid = models.ForeignKey(Infofeed, db_column='infofeedId')
    hostgroupid = models.ForeignKey(Hostgroup, db_column='hostGroupId')

    class Meta:
        db_table = 'Infofeed_HostGroup'
        unique_together = (('infofeedid', 'hostgroupid'),)
        index_together = (('infofeedid', 'hostgroupid'),)


class InfofeedHostgroupExcludedHosts(models.Model):
    id = models.AutoField(primary_key=True)
    infofeedhostgroupid = models.ForeignKey(
        InfofeedHostgroup, db_column='infofeedHostGroupId'
    )
    hostid = models.ForeignKey(Host, db_column='hostId')

    class Meta:
        db_table = 'Infofeed_HostGroup_Excluded_Hosts'
        unique_together = (('infofeedhostgroupid', 'hostid'),)
        index_together = (('infofeedhostgroupid', 'hostid'),)


class InfofeedNotificationtype(models.Model):
    id = models.AutoField(primary_key=True)
    infofeedid = models.ForeignKey(Infofeed, db_column='infofeedId')
    slaactionid = models.ForeignKey('Slaaction', db_column='slaActionId')

    class Meta:
        db_table = 'Infofeed_NotificationType'
        unique_together = (('infofeedid', 'slaactionid'),)
        index_together = (('infofeedid', 'slaactionid'),)


class McMc(models.Model):
    id = models.AutoField(primary_key=True)
    checklistid = models.ForeignKey(
        'Maintenancechecklist',
        db_column='checklistId',
        related_name='checklist_mcmc_set'
    )
    parentid = models.ForeignKey(
        'Maintenancechecklist',
        db_column='parentId',
        related_name='parent_mcmc_set'
    )

    class Meta:
        db_table = 'MC_MC'
        unique_together = (('checklistid', 'parentid'),)
        index_together = (('checklistid', 'parentid'),)


class Maintenancechecklist(models.Model):
    id = models.AutoField(primary_key=True)
    name = models.CharField(unique=True, max_length=255)
    comment = models.TextField()
    istemplate = models.BooleanField(default=False, db_column='isTemplate')

    class Meta:
        db_table = 'MaintenanceChecklist'


class Maintenancechecklistquestion(models.Model):
    id = models.AutoField(primary_key=True)
    name = models.CharField(max_length=255)
    comment = models.TextField()

    class Meta:
        db_table = 'MaintenanceChecklistQuestion'


class MaintenancechecklistExcludedquestion(models.Model):
    id = models.AutoField(primary_key=True)
    hostid = models.ForeignKey(Host, db_column='hostId', null=True)
    groupid = models.ForeignKey(
        'Maintenancegroup', db_column='groupId', null=True
    )
    checklist_questionid = models.ForeignKey(
        'Maintenancechecklist_Question', db_column='checklist_questionId'
    )

    class Meta:
        db_table = 'MaintenanceChecklist_ExcludedQuestion'


class MaintenancechecklistHost(models.Model):
    id = models.AutoField(primary_key=True)
    checklistid = models.ForeignKey(
        Maintenancechecklist, db_column='checklistId'
    )
    hostid = models.ForeignKey(Host, db_column='hostId')

    class Meta:
        db_table = 'MaintenanceChecklist_Host'
        unique_together = (('checklistid', 'hostid'),)
        index_together = (('checklistid', 'hostid'),)


class MaintenancechecklistMaintenancegroup(models.Model):
    checklistid = models.ForeignKey(
        Maintenancechecklist, db_column='checklistId'
    )
    groupid = models.ForeignKey('Maintenancegroup', db_column='groupId')

    class Meta:
        db_table = 'MaintenanceChecklist_MaintenanceGroup'


class Maintenancechecklist_Question(models.Model):
    id = models.AutoField(primary_key=True)
    questionid = models.ForeignKey(
        Maintenancechecklistquestion, db_column='questionId'
    )
    checklistid = models.ForeignKey(
        Maintenancechecklist, db_column='checklistId'
    )

    class Meta:
        db_table = 'MaintenanceChecklist_Question'


class Maintenancecomment(models.Model):
    id = models.AutoField(primary_key=True)
    tickethostid = models.ForeignKey(
        'Maintenancetickethost', db_column='ticketHostId'
    )
    userid = models.ForeignKey('User', null=True, db_column='userId')
    oldstateid = models.ForeignKey(
        'Maintenancestate',
        db_column='oldStateId',
        null=True,
        related_name='old_state_maintenancecomment_set',
    )
    newstateid = models.ForeignKey(
        'Maintenancestate',
        db_column='newStateId',
        null=True,
        related_name='new_state_maintenancecomment_set',
    )
    oldosversionid = models.ForeignKey(
        Hostosversion,
        db_column='oldOsVersionId',
        null=True,
        related_name='old_version_maintenancecomment_set',
    )
    newosversionid = models.ForeignKey(
        Hostosversion,
        db_column='newOsVersionId',
        null=True,
        related_name='new_version_maintenancecomment_set',
    )
    timestamp = models.DateTimeField(auto_now_add=True)
    comment = models.TextField(blank=True, null=True)

    class Meta:
        db_table = 'MaintenanceComment'


class MaintenancecommentMaintenancetag(models.Model):
    id = models.AutoField(primary_key=True)
    commentid = models.ForeignKey(Maintenancecomment, db_column='commentId')
    tagid = models.ForeignKey('Maintenancetag', db_column='tagId')

    class Meta:
        db_table = 'MaintenanceComment_MaintenanceTag'
        unique_together = (('commentid', 'tagid'),)
        index_together = (('commentid', 'tagid'),)


class Maintenancecycle(models.Model):
    id = models.AutoField(primary_key=True)
    name = models.CharField(max_length=255)
    interval = models.IntegerField()

    class Meta:
        db_table = 'MaintenanceCycle'


class Maintenancegroup(models.Model):
    id = models.AutoField(primary_key=True)
    customerid = models.ForeignKey(
        Customer, db_column='customerId', null=False
    )
    maintenancecycleid = models.ForeignKey(
        Maintenancecycle, db_column='maintenanceCycleId', null=True
    )
    name = models.CharField(max_length=40)
    description = models.CharField(max_length=255, blank=True)
    datestart = models.DateField(db_column='dateStart', null=True)

    class Meta:
        db_table = 'MaintenanceGroup'


class MaintenancegroupHost(models.Model):
    id = models.AutoField(primary_key=True)
    hostid = models.ForeignKey(Host, db_column='hostId')
    groupid = models.ForeignKey(Maintenancegroup, db_column='groupId')

    class Meta:
        db_table = 'MaintenanceGroup_Host'
        unique_together = (('hostid', 'groupid'),)
        index_together = (('hostid', 'groupid'),)


class MaintenancehostQuestion(models.Model):
    id = models.AutoField(primary_key=True)
    tickethostid = models.ForeignKey(
        'Maintenancetickethost', db_column='ticketHostId'
    )
    questionid = models.ForeignKey(
        Maintenancechecklistquestion, db_column='questionId'
    )
    comment = models.TextField(blank=True, null=True)
    ischecked = models.BooleanField(default=False, db_column='isChecked')

    class Meta:
        db_table = 'MaintenanceHost_Question'
        unique_together = (('tickethostid', 'questionid'),)
        index_together = (('tickethostid', 'questionid'),)


class Maintenancestate(models.Model):
    id = models.AutoField(primary_key=True)
    name = models.CharField(max_length=255)

    class Meta:
        db_table = 'MaintenanceState'


class Maintenancetag(models.Model):
    id = models.AutoField(primary_key=True)
    name = models.CharField(unique=True, max_length=255)
    description = models.CharField(max_length=255, blank=True)

    class Meta:
        db_table = 'MaintenanceTag'


class Maintenanceticket(models.Model):
    id = models.AutoField(primary_key=True)
    customerid = models.ForeignKey(
        Customer, db_column='customerId', null=False
    )
    groupid = models.ForeignKey(
        Maintenancegroup, db_column='groupId', null=True
    )
    userid = models.ForeignKey('User', db_column='userId', null=True)
    datecreated = models.DateField(db_column='dateCreated')
    datedue = models.DateField(db_column='dateDue', null=True)
    datearchived = models.DateField(db_column='dateArchived', null=True)

    class Meta:
        db_table = 'MaintenanceTicket'


class Maintenancetickethost(models.Model):
    id = models.AutoField(primary_key=True)
    ticketid = models.ForeignKey(Maintenanceticket, db_column='ticketId')
    hostid = models.ForeignKey(Host, db_column='hostId')
    stateid = models.ForeignKey(Maintenancestate, db_column='stateId')
    datetimechanged = models.DateTimeField(db_column='datetimeChanged')

    class Meta:
        db_table = 'MaintenanceTicketHost'


class Nagioslog(models.Model):
    OBJECT_TYPE_HOST    = 'HOST'
    OBJECT_TYPE_SERVICE = 'SERVICE'

    CHOICES_OBJECT_TYPE = (
        (OBJECT_TYPE_HOST,    OBJECT_TYPE_HOST),
        (OBJECT_TYPE_SERVICE, OBJECT_TYPE_SERVICE),
    )

    STATE_TYPE_SOFT = 'SOFT'
    STATE_TYPE_HARD = 'HARD'

    CHOICES_STATE_TYPE = (
        (STATE_TYPE_SOFT, STATE_TYPE_SOFT),
        (STATE_TYPE_HARD, STATE_TYPE_HARD),
    )

    STATE_UP          = 'UP'
    STATE_DOWN        = 'DOWN'
    STATE_UNREACHABLE = 'UNREACHABLE'
    STATE_OK          = 'OK'
    STATE_WARNING     = 'WARNING'
    STATE_UNKNOWN     = 'UNKNOWN'
    STATE_CRITICAL    = 'CRITICAL'

    CHOICES_STATE = (
        (STATE_UP,          STATE_UP),
        (STATE_DOWN,        STATE_DOWN),
        (STATE_UNREACHABLE, STATE_UNREACHABLE),
        (STATE_OK,          STATE_OK),
        (STATE_WARNING,     STATE_WARNING),
        (STATE_UNKNOWN,     STATE_UNKNOWN),
        (STATE_CRITICAL,    STATE_CRITICAL),
    )

    id = models.AutoField(primary_key=True)
    timestamp = models.DateTimeField(auto_now_add=True)
    objecttype = models.CharField(
        db_column='objectType',
        max_length=7,
        choices=CHOICES_OBJECT_TYPE
    )
    statetype = models.CharField(
        db_column='stateType',
        max_length=4,
        choices=CHOICES_STATE_TYPE,
    )
    state = models.CharField(
        max_length=11,
        choices=CHOICES_STATE
    )
    name = models.CharField(max_length=255)
    hostname = models.CharField(max_length=255)
    checkcommand = models.CharField(db_column='checkCommand', max_length=32)
    address = models.CharField(max_length=39)
    output = models.TextField()
    perfdata = models.TextField(null=True)
    duration = models.CharField(max_length=11)
    datetime = models.DateTimeField()
    attempt = models.IntegerField()
    processed = models.CharField(max_length=2, default='0', db_index=True)
    problemid = models.IntegerField(db_column='problemId', db_index=True)
    lastproblemid = models.IntegerField(
        db_column='lastProblemId', db_index=True
    )
    alert = models.ForeignKey(Alert, db_column='alertId', null=True)

    class Meta:
        db_table = 'NagiosLog'
        index_together = ['name', 'hostname']


class Notificationsetting(models.Model):
    id = models.AutoField(primary_key=True)
    customerid = models.ForeignKey(Customer, db_column='customerId')
    enabled = models.BooleanField(default=False)
    slaactionid = models.ForeignKey('Slaaction', db_column='slaActionId')

    class Meta:
        db_table = 'NotificationSetting'


class Notificationtype(models.Model):
    id = models.AutoField(primary_key=True)
    name = models.CharField(max_length=32)
    description = models.CharField(max_length=255)
    multiple = models.BooleanField(default=True)
    repeats = models.IntegerField()

    class Meta:
        db_table = 'NotificationType'


class Permission(models.Model):
    id = models.AutoField(primary_key=True)
    name = models.CharField(unique=True, max_length=32)
    description = models.CharField(max_length=255)
    globalonly = models.BooleanField(
        default=False,
        db_column='globalOnly'
    )

    class Meta:
        db_table = 'Permission'


class Report(models.Model):
    id = models.AutoField(primary_key=True)
    timestamp = models.DateTimeField(auto_now_add=True)
    userid = models.ForeignKey('User', db_column='userId')
    customerid = models.ForeignKey('Customer', db_column='customerId')
    datefrom = models.DateTimeField(db_column='dateFrom')
    dateto = models.DateTimeField(db_column='dateTo')
    istemplate = models.IntegerField(db_column='isTemplate')

    class Meta:
        db_table = 'Report'


class ReportHost(models.Model):
    id = models.AutoField(primary_key=True)
    reportid = models.ForeignKey(Report, db_column='reportId')
    hostid = models.ForeignKey(Host, db_column='hostId')

    class Meta:
        db_table = 'Report_Host'


class Role(models.Model):
    id = models.AutoField(primary_key=True)
    name = models.CharField(unique=True, max_length=32)
    description = models.CharField(max_length=255)
    ldapgroup = models.CharField(
        db_column='ldapGroup', max_length=255, null=True
    )

    class Meta:
        db_table = 'Role'


class RolePermission(models.Model):
    id = models.AutoField(primary_key=True)
    roleid = models.ForeignKey(Role, db_column='roleId')
    permissionid = models.ForeignKey(Permission, db_column='permissionId')

    class Meta:
        db_table = 'Role_Permission'


class RoleRole(models.Model):
    id = models.AutoField(primary_key=True)
    roleid = models.ForeignKey(
        Role,
        db_column='roleId',
        related_name='role_rolerole_set',
    )
    assignedroleid = models.ForeignKey(
        Role,
        db_column='assignedRoleId',
        related_name='assigned_rolerole_set',
    )

    class Meta:
        db_table = 'Role_Role'


class Sla(models.Model):
    id = models.AutoField(primary_key=True)
    customerid = models.ForeignKey(Customer, db_column='customerId', null=True)
    name = models.CharField(unique=True, max_length=32)
    description = models.TextField()
    delaycycle = models.IntegerField(db_column='delayCycle')
    delayrestart = models.IntegerField(db_column='delayRestart')
    timeout = models.IntegerField()
    minavailability = models.FloatField(db_column='minAvailability')
    isdeleted = models.BooleanField(db_column='isDeleted', default=False)

    class Meta:
        db_table = 'SLA'


class Slaaction(models.Model):
    id = models.AutoField(primary_key=True)
    name = models.CharField(max_length=32)
    description = models.CharField(max_length=255)
    multiple = models.BooleanField(default=True)
    repeats = models.IntegerField(default=5)
    delay = models.IntegerField(default=0)

    class Meta:
        db_table = 'SLAAction'


class Service(models.Model):
    id = models.AutoField(primary_key=True)
    commandid = models.ForeignKey(Command, db_column='commandId', related_name='services')  # noqa
    customerid = models.ForeignKey(Customer, db_column='customerId', null=True)
    slaid = models.ForeignKey(Sla, db_column='slaId', null=True)
    name = models.CharField(unique=True, max_length=255)
    description = models.CharField(max_length=255)
    maxcheckattempts = models.IntegerField(db_column='maxCheckAttempts')
    checkinterval = models.IntegerField(db_column='checkInterval')
    retryinterval = models.IntegerField(db_column='retryInterval')
    freshness = models.IntegerField()
    isnrpe = models.BooleanField(
        db_column='isNrpe',
        db_index=True,
        default=False
    )
    isdeleted = models.BooleanField(db_column='isDeleted', default=False)

    @property
    def command(self):
        if self.isnrpe:
            return '%s!%s' % (self.commandid.name, self.name)
        else:
            arguments = Serviceargument.objects.filter(
                serviceid=self
            ).order_by('-position')

            if arguments:
                args = '!'.join([arg.value for arg in arguments])
                return '%s!%s' % (self.commandid.name, args)
            else:
                return self.commandid.name

    class Meta:
        db_table = 'Service'


class Serviceargument(models.Model):
    TYPE_FIXED    = 'Fixed'
    TYPE_VARIABLE = 'Variable'

    CHOICES_TYPE = (
        (TYPE_FIXED,    TYPE_FIXED),
        (TYPE_VARIABLE, TYPE_VARIABLE),
    )

    id = models.AutoField(primary_key=True)
    serviceid = models.ForeignKey(Service, db_column='serviceId')
    position = models.IntegerField(db_index=True)
    option = models.CharField(max_length=255, blank=True, null=True)
    value = models.CharField(max_length=255, blank=True, null=True)
    description = models.CharField(max_length=255, blank=True, null=True)
    type = models.CharField(max_length=8, choices=CHOICES_TYPE)

    class Meta:
        db_table = 'ServiceArgument'


class Servicegroup(models.Model):
    id = models.AutoField(primary_key=True)
    customerid = models.ForeignKey(Customer, db_column='customerId', null=True)
    name = models.CharField(max_length=255)
    description = models.CharField(max_length=255)

    class Meta:
        db_table = 'ServiceGroup'


class Servicegroupmember(models.Model):
    id = models.AutoField(primary_key=True)
    groupid = models.ForeignKey(Servicegroup, db_column='groupId')
    serviceid = models.ForeignKey(Service, db_column='serviceId')
    ispassive = models.BooleanField(db_column='isPassive', default=False)
    isenabled = models.BooleanField(db_column='isEnabled', default=True)

    class Meta:
        db_table = 'ServiceGroupMember'
        unique_together = (('groupid', 'serviceid'),)
        index_together = (('groupid', 'serviceid'),)


class Setting(models.Model):
    key = models.CharField(primary_key=True, max_length=255)
    value = models.CharField(max_length=255, blank=True, null=True)

    class Meta:
        db_table = 'Setting'


class Timeframe(models.Model):
    id = models.AutoField(primary_key=True)
    monday = models.BooleanField(default=False)
    tuesday = models.BooleanField(default=False)
    wednesday = models.BooleanField(default=False)
    thursday = models.BooleanField(default=False)
    friday = models.BooleanField(default=False)
    saturday = models.BooleanField(default=False)
    sunday = models.BooleanField(default=False)
    timefrom = models.TimeField(db_column='timeFrom')
    timeto = models.TimeField(db_column='timeTo')
    slaid = models.ForeignKey(Sla, db_column='slaId')
    customerid = models.ForeignKey(Customer, db_column='customerId', null=True)

    class Meta:
        db_table = 'Timeframe'


class Timeframerule(models.Model):
    id = models.AutoField(primary_key=True)
    actionid = models.ForeignKey(Slaaction, db_column='actionId')
    delay = models.IntegerField()
    timeframeid = models.ForeignKey(Timeframe, db_column='timeframeId')

    class Meta:
        db_table = 'TimeframeRule'


class User(models.Model):
    METHOD_LDAP = 'LDAP'
    METHOD_MYSQL = 'MYSQL'
    METHOD_LOCAL = 'LOCAL'

    CHOICES_METHOD = (
        (METHOD_LDAP,  METHOD_LDAP),
        (METHOD_MYSQL, METHOD_MYSQL),
    )

    id = models.AutoField(primary_key=True)
    customerid = models.ForeignKey(Customer, db_column='customerId')
    name = models.CharField(unique=True, max_length=32)
    fullname = models.CharField(db_column='fullName', max_length=255)
    passwordhash = models.CharField(
        db_column='passwordHash', max_length=40, null=True
    )
    passwordsalt = models.CharField(
        db_column='passwordSalt', max_length=32, null=True
    )
    phone = models.CharField(max_length=20, null=True)
    sms = models.CharField(max_length=20, null=True)
    email = models.CharField(max_length=255, null=True)
    jabber = models.CharField(max_length=255, null=True)
    mattermost = models.CharField(max_length=255, null=True)
    authenticationmethod = models.CharField(
        db_column='authenticationMethod',
        max_length=10,
        choices=CHOICES_METHOD
    )
    emergency = models.BooleanField(default=False)
    isenabled = models.BooleanField(db_column='isEnabled', default=True)
    isdeleted = models.BooleanField(db_column='isDeleted', default=False)

    class Meta:
        db_table = 'User'


class Userlogin(models.Model):
    id = models.AutoField(primary_key=True)
    userid = models.ForeignKey(User, db_column='userId', db_index=True)
    timestamp = models.DateTimeField(auto_now_add=True)
    ip = models.CharField(db_column='IP', max_length=15)

    class Meta:
        db_table = 'UserLogin'


class UserCustomer(models.Model):
    id = models.AutoField(primary_key=True)
    userid = models.ForeignKey(User, db_column='userId')
    customerid = models.ForeignKey(Customer, db_column='customerId')

    class Meta:
        db_table = 'User_Customer'
        unique_together = (('userid', 'customerid'),)
        index_together = (('userid', 'customerid'),)


class UserRoleCustomer(models.Model):
    id = models.AutoField(primary_key=True)
    roleid = models.ForeignKey('Role', db_column='roleId')
    usercustomerid = models.ForeignKey(
        UserCustomer,
        db_column='userCustomerId'
    )

    class Meta:
        db_table = 'User_Role_Customer'
        unique_together = (('roleid', 'usercustomerid'),)
        index_together = (('roleid', 'usercustomerid'),)
